==> javascript-starfield-1.0.2.tgz: package/readme.md <==
# Starfield Animation

(Original Vietnamese below)

_Starfield is a JavaScript package that generates a dynamic starfield background with radiating stars. It features customizable star sizes, speeds, and colors, perfect for adding a cosmic touch to websites or applications._

## Installation Guide

To install, use npm:

```
npm install starfield
```

No additional dependencies are required beyond a modern browser.

## Purpose

– Create a starfield background with stars radiating from the center.

– Automatically adjust to window size and visibility state.

– Provide an option to stop and clean up the animation.

## Workflow

1. Include the package: Add the script to your HTML or import it in your JavaScript project.

2. Automatic activation: The starfield starts animating when the DOM is loaded and adapts to window resizing or visibility changes.

3. Manual control (optional): Use `initStarfield()` to start manually or `destroy()` to stop and remove the animation.

Example usage in HTML:

```
<script src="node_modules/starfield/index.js"></script>
```

Example usage in JavaScript:

```
const { initStarfield } = require('starfield');
initStarfield();
starfield.destroy();
```

## Contact & Support

– Email: info@nhavantuonglai.com.

– Website: [nhavantuonglai.com](https://nhavantuonglai.com).

If you have any questions or suggestions, feel free to reach out for the fastest support.

Don’t forget to star this repository if you find it useful.

# Hiệu ứng trường sao

_Hiệu ứng trường sao là một gói JavaScript tạo ra một nền trường sao động với các ngôi sao tỏa ra từ trung tâm. Nó có kích thước, tốc độ và màu sắc ngôi sao tùy chỉnh, hoàn hảo để thêm nét vũ trụ vào trang web hoặc ứng dụng._

## Hướng dẫn cài đặt

Để cài đặt, sử dụng npm:

```
npm install starfield
```

Không yêu cầu thêm thư viện phụ thuộc ngoài trình duyệt hiện đại.

## Công dụng

– Tạo nền trường sao với các ngôi sao tỏa ra từ trung tâm.

– Tự động điều chỉnh theo kích thước cửa sổ và trạng thái hiển thị.

– Cung cấp tùy chọn dừng và dọn dẹp hoạt hình.

## Flow thao tác

1. Thêm gói: Thêm script vào HTML hoặc nhập vào dự án JavaScript của bạn.

2. Kích hoạt tự động: Trường sao bắt đầu hoạt hình khi DOM được tải và thích nghi với thay đổi kích thước cửa sổ hoặc trạng thái hiển thị.

3. Điều khiển thủ công (tùy chọn): Sử dụng `initStarfield()` để bắt đầu thủ công hoặc `destroy()` để dừng và xóa hoạt hình.

Ví dụ sử dụng trong HTML:

```
<script src="node_modules/starfield/index.js"></script>
```

Ví dụ sử dụng trong JavaScript:

```
const { initStarfield } = require('starfield');
initStarfield();
starfield.destroy();
```

## Liên hệ & Hỗ trợ

– Email: info@nhavantuonglai.com.

– Website: [nhavantuonglai.com](https://nhavantuonglai.com).

Nếu bạn có câu hỏi hoặc đề xuất, đừng ngần ngại liên hệ để được hỗ trợ nhanh nhất.

Đừng quên star repository này nếu bạn thấy nó hữu ích.

==> javascript-starfield-1.0.3.tgz: package/readme.md <==
# Starfield Animation

(Original Vietnamese below)

_Starfield is a JavaScript package that generates a dynamic starfield background with radiating stars. It features customizable star sizes, speeds, and colors, perfect for adding a cosmic touch to websites or applications._

## Installation Guide

To install, use npm:

```
npm install javascript-starfield
```

No additional dependencies are required beyond a modern browser.

## Purpose

– Create a starfield background with stars radiating from the center.

– Automatically adjust to window size and visibility state.

– Provide an option to stop and clean up the animation.

## Workflow

1. Include the package: Add the script to your HTML or import it in your JavaScript project.

2. Automatic activation: The starfield starts animating when the DOM is loaded and adapts to window resizing or visibility changes.

3. Manual control (optional): Use `initStarfield()` to start manually or `destroy()` to stop and remove the animation.

Example usage in HTML:

```
<script src="node_modules/javascript-starfield/index.js"></script>
```

Example usage in JavaScript:

```
const { initStarfield } = require('javascript-starfield');
initStarfield();
javascript-starfield.destroy();
```

## Contact & Support

– Email: info@nhavantuonglai.com.

– Website: [nhavantuonglai.com](https://nhavantuonglai.com).

If you have any questions or suggestions, feel free to reach out for the fastest support.

Don’t forget to star this repository if you find it useful.

# Hiệu ứng trường sao

_Hiệu ứng trường sao là một gói JavaScript tạo ra một nền trường sao động với các ngôi sao tỏa ra từ trung tâm. Nó có kích thước, tốc độ và màu sắc ngôi sao tùy chỉnh, hoàn hảo để thêm nét vũ trụ vào trang web hoặc ứng dụng._

## Hướng dẫn cài đặt

Để cài đặt, sử dụng npm:

```
npm install javascript-starfield
```

Không yêu cầu thêm thư viện phụ thuộc ngoài trình duyệt hiện đại.

## Công dụng

– Tạo nền trường sao với các ngôi sao tỏa ra từ trung tâm.

– Tự động điều chỉnh theo kích thước cửa sổ và trạng thái hiển thị.

– Cung cấp tùy chọn dừng và dọn dẹp hoạt hình.

## Flow thao tác

1. Thêm gói: Thêm script vào HTML hoặc nhập vào dự án JavaScript của bạn.

2. Kích hoạt tự động: Trường sao bắt đầu hoạt hình khi DOM được tải và thích nghi với thay đổi kích thước cửa sổ hoặc trạng thái hiển thị.

3. Điều khiển thủ công (tùy chọn): Sử dụng `initStarfield()` để bắt đầu thủ công hoặc `destroy()` để dừng và xóa hoạt hình.

Ví dụ sử dụng trong HTML:

```
<script src="node_modules/javascript-starfield/index.js"></script>
```

Ví dụ sử dụng trong JavaScript:

```
const { initStarfield } = require('javascript-starfield');
initStarfield();
javascript-starfield.destroy();
```

## Liên hệ & Hỗ trợ

– Email: info@nhavantuonglai.com.

– Website: [nhavantuonglai.com](https://nhavantuonglai.com).

Nếu bạn có câu hỏi hoặc đề xuất, đừng ngần ngại liên hệ để được hỗ trợ nhanh nhất.

Đừng quên star repository này nếu bạn thấy nó hữu ích.
